@@ -22,7 +22,7 @@ from cctrl.settings import VERSION
 
 from pycclib import cclib
 from cctrl.error import InputErrorException, messages
-from cctrl.auth import get_credentials, update_tokenfile, delete_tokenfile, read_tokenfile
+from cctrl.auth import get_email, get_password, update_tokenfile, delete_tokenfile, read_tokenfile
 from cctrl.app import ParseAppDeploymentName
 
 
@@ -65,16 +65,25 @@ def init_api(settings):
             break
 
         dirname = os.path.dirname(dirname)
-    return cclib.API(token=read_tokenfile(), url=settings.api_url, token_source_url=settings.token_source_url, register_addon_url=settings.register_addon_url, encode_email=settings.encode_email)
+    return cclib.API(token=read_tokenfile(),
+                     url=settings.api_url,
+                     token_source_url=settings.token_source_url,
+                     register_addon_url=settings.register_addon_url,
+                     encode_email=settings.encode_email)
 
 
 def get_email_and_password(settings):
     # check ENV for credentials first
     try:
-        email = os.environ.pop('CCTRL_EMAIL')
-        password = os.environ.pop('CCTRL_PASSWORD')
+        email = os.environ.pop(settings.login_creds['email'])
     except KeyError:
-        email, password = get_credentials(settings)
+        email = get_email(settings)
+
+    try:
+        password = os.environ.pop(settings.login_creds['pwd'])
+    except KeyError:
+        password = get_password()
+
     return email, password
 
 
